@@ -244,6 +244,16 @@ void ExtractJob::fillInDefaultValues(ExtractionOptions& options)
     }
 }
 
+QString ExtractJob::destinationDirectory() const
+{
+    return m_destinationDir;
+}
+
+ExtractionOptions ExtractJob::extractionOptions() const
+{
+    return m_options;
+}
+
 AddJob::AddJob(const QStringList& files, const CompressionOptions& options , ReadWriteArchiveInterface *interface, QObject *parent)
     : Job(interface, parent)
     , m_files(files)
