@@ -79,7 +79,7 @@ private slots:
     void slotAddFilesDone(KJob*);
     void slotDeleteFiles();
     void slotDeleteFilesDone(KJob*);
-    void slotUpdateSplitterSizes();
+    void updateSplitterSizes();
     void slotToggleInfoPanel(bool);
     void slotSaveAs();
     void updateActions();
@@ -116,7 +116,6 @@ private:
     QSplitter            *m_splitter;
     KTempDir             *m_previewDir;
     bool                  m_busy;
-    QString               m_destinationDirectory;
 
     KAbstractWidgetJobTracker  *m_jobTracker;
     KParts::StatusBarExtension *m_statusBarExtension;
