@@ -100,7 +100,6 @@ KGpgGenerateKey::postStart()
 	keymessage.append("\nPassphrase: ");
 	write(keymessage, false);
 
-	QApplication::restoreOverrideCursor();
 	QString passdlgmessage;
 	if (!m_email.isEmpty()) {
 		passdlgmessage = i18n("<p><b>Enter passphrase for %1 &lt;%2&gt;</b>:<br />Passphrase should include non alphanumeric characters and random sequences.</p>", m_name, m_email);
@@ -108,11 +107,8 @@ KGpgGenerateKey::postStart()
 		passdlgmessage = i18n("<p><b>Enter passphrase for %1</b>:<br />Passphrase should include non alphanumeric characters and random sequences.</p>", m_name);
 	}
 
-	if (sendPassphrase(passdlgmessage, true)) {
-		setSuccess(TS_USER_ABORTED);
-	}
-	QApplication::setOverrideCursor(Qt::BusyCursor);
-	write("%commit");
+	QApplication::restoreOverrideCursor();
+	askNewPassphrase(passdlgmessage);
 }
 
 bool
@@ -169,7 +165,32 @@ KGpgGenerateKey::nextLine(const QString &line)
 void
 KGpgGenerateKey::finish()
 {
-	emit statusMessage(i18n("Key %1 generated", getFingerprint()));
+	switch (getSuccess()) {
+	case TS_BAD_PASSPHRASE:
+		emit statusMessage(i18n("Bad passphrase. Cannot generate a new key pair."));
+		break;
+	case TS_USER_ABORTED:
+		emit statusMessage(i18n("Aborted by the user. Cannot generate a new key pair."));
+		break;
+	case TS_INVALID_EMAIL:
+		emit statusMessage(i18n("The email address is not valid. Cannot generate a new key pair."));
+		break;
+	case TS_INVALID_NAME:
+		emit statusMessage(i18n("The name is not accepted by gpg. Cannot generate a new key pair."));
+		break;
+	case TS_OK:
+		emit statusMessage(i18n("Key %1 generated", getFingerprint()));
+		break;
+	default:
+		emit statusMessage(i18n("gpg process did not finish. Cannot generate a new key pair."));
+	}
+}
+
+void
+KGpgGenerateKey::newPasswordEntered()
+{
+	QApplication::setOverrideCursor(Qt::BusyCursor);
+	write("%commit");
 }
 
 void
